@@ -116,6 +116,20 @@ void cyclopsSetBeta(SEXP inRcppCcdInterface, const std::vector<double>& beta) {
     interface->getCcd().setBeta(beta);
 }
 
+// [[Rcpp::export(.cyclopsGetBeta)]]
+double cyclopsGetBeta(SEXP inRcppCcdInterface, const int index) {
+	using namespace bsccs;
+	XPtr<RcppCcdInterface> interface(inRcppCcdInterface);
+	return interface->getCcd().getBeta(index);
+}
+
+// [[Rcpp::export(.cyclopsSetStartingBeta)]]
+void cyclopsSetStartingBeta(SEXP inRcppCcdInterface, const std::vector<double>& inStartingBeta) {
+	using namespace bsccs;
+	XPtr<RcppCcdInterface> interface(inRcppCcdInterface);
+	interface->getCcd().setStartingBeta(inStartingBeta);
+}
+
 // [[Rcpp::export(.cyclopsSetFixedBeta)]]
 void cyclopsSetFixedBeta(SEXP inRcppCcdInterface, int beta, bool fixed) {
     using namespace bsccs;
@@ -124,6 +138,14 @@ void cyclopsSetFixedBeta(SEXP inRcppCcdInterface, int beta, bool fixed) {
     interface->getCcd().setFixedBeta(beta - 1, fixed);
 }
 
+// [[Rcpp::export(.cyclopsGetFixedBeta)]]
+bool cyclopsGetFixedBeta(SEXP inRcppCcdInterface, const int index){
+	using namespace bsccs;
+	XPtr<RcppCcdInterface> interface(inRcppCcdInterface);
+	return interface->getCcd().getFixedBeta(index);
+}
+
+
 // [[Rcpp::export(".cyclopsGetIsRegularized")]]
 bool cyclopsGetIsRegularized(SEXP inRcppCcdInterface, const int index) {
     using namespace bsccs;
