@@ -133,6 +133,8 @@ public:
 //	template <typename T>
 	void setBeta(const std::vector<double>& beta);
 
+	void setStartingBeta(const std::vector<double>& inStartingBeta);
+	
 	void setBeta(int i, double beta);
 
 //	void double getHessianComponent(int i, int j);
@@ -330,6 +332,7 @@ protected:
 
 	typedef std::vector<double> DoubleVector;
 	DoubleVector hBeta;
+	DoubleVector startingBeta;
 
 // 	DoubleVector& hXBeta; // TODO Delegate to ModelSpecifics
 // 	DoubleVector& hXBetaSave; // Delegate
@@ -343,7 +346,7 @@ protected:
 	string conditionId;
 
 	bool computeMLE;
-	int priorType;
+	int priorType = priors::NONE;
 
 	double initialBound;
 
